@@ -38,10 +38,7 @@ class ExaSQLThread(threading.Thread):
 
             # In case of SQL error stop HTTP server, close pipes and interrupt I/O in callback function
             if self.http_thread:
-                if self.__class__ == ExaSQLExportThread:
-                    self.http_thread.terminate_export()
-                elif self.__class__ == ExaSQLImportThread:
-                    self.http_thread.terminate_import()
+                self.http_thread.terminate()
 
     def run_sql(self):
         pass
@@ -96,7 +93,7 @@ class ExaSQLThread(threading.Thread):
 
 class ExaSQLExportThread(ExaSQLThread):
     """
-    Build and run IMPORT query into separate thread
+    Build and run EXPORT query into separate thread
     Main thread is busy outputting data in callbacks
     """
     def __init__(self, connection, compression, query_or_table, export_params):
@@ -250,21 +247,12 @@ class ExaHttpThread(threading.Thread):
         if self.exc:
             raise self.exc
 
-    def terminate_export(self):
+    def terminate(self):
         self.server.is_terminated = True
         self.server.can_finish_get.set()
 
         # Must close pipes here to prevent infinite lock in callback function
         # Termination pipe order is important for Windows
-        self.read_pipe.close()
-        self.write_pipe.close()
-
-    def terminate_import(self):
-        self.server.is_terminated = True
-        self.server.can_finish_get.set()
-
-        # Must close pipes here to prevent infinite lock in callback function in case of SQL error
-        # Termination pipe order is important for Windows
         self.write_pipe.close()
         self.read_pipe.close()
 
